import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "./view"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Окно отображения QR-кода
 * @param fullScreen диалог является полноэкранным
 */
BasicView {
    id: dialog

    readonly property bool fullScreen: true

    implicitWidth: Screen.desktopAvailableWidth
    implicitHeight: Screen.desktopAvailableHeight

    RowLayout {
        anchors.fill: parent
        spacing: 0
        Rectangle {
            color: Style.parameter("color.modalBackground")
            Layout.fillWidth: true
            Layout.fillHeight: true
            ColumnLayout {
                anchors.centerIn: parent
                spacing: 0
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "scanQrCodeTitle"
                    Tr { code: "scanQrCodeFormTitle"; defaultMessage: "Оплата по QR-коду" }
                }
                Item {
                    Layout.preferredHeight: 16
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "scanQrCodeMessage"
                    Tr { code: "scanQrCodeFormMessage"; defaultMessage: "Отсканируйте при помощи телефона" }
                }
                Item {
                    Layout.preferredHeight: 96
                }
                Image {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: 296
                    Layout.preferredHeight: 296
                    source: "data:image/png;base64," + Utils.generateQr(params.qrCode, 296)
                }
                Item {
                    Layout.preferredHeight: 116
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "scanQrCodeHint"
                    Tr {
                        code: "scanQrCodeFormHint"
                        defaultMessage: "Операция будет автоматически отменена через %1 сек."
                        args: [ timer.secondsLeft ]
                    }
                }
            }
        }
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: Math.floor((Screen.desktopAvailableWidth * 0.1 + 201) / 8) * 8
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            BasicButton {
                Style.class: "scanQrCodeCancel"
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    bottom: parent.bottom
                    bottomMargin: 24
                }
                width: 256; height: 68
                Tr { code: "scanQrCodeFormCancel"; defaultMessage: "Отмена" }
                onClicked: {
                    let args = {}
                    args["data"] = false
                    handler.sendAnswer(args)
                }
            }
        }
    }
    footer: BottomPanel {}

    DialogHandler { id: handler }

    Timer {
        id: timer
        property int secondsLeft: params.timeout
        interval: 1000
        running: secondsLeft > 0
        repeat: true
        onTriggered: --secondsLeft
    }
}
