import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"
import "./view"

import Artix.Handlers
import Artix.Core
import Artix.Models

/**
 * @brief Диалог выбора смены
 */
ChoiceTable {
    id: root
    model: ShiftChoiceModel { id: model; filter: root.filter }
    titleTr: Utils.makeTr("shiftChoiceTitle", "Выберите смену")
    okButtonTr: Utils.makeTr("shiftChoiceFormOk", "Выбрать")
    cancelButtonTr: Utils.makeTr("shiftChoiceFormCancel", "Назад")
    inputPlaceholderTr: Utils.makeTr("shiftChoiceFormEditText", "Номер смены")
    columnsOrder: [
        "shiftnum",
        "time_beg",
        "time_end",
        "name",
    ]
    columnsHorizontalAlignment: [
        Qt.AlignLeft,   // Номер смены
        Qt.AlignLeft,   // Дата открытия
        Qt.AlignLeft,   // Дата закрытия
        Qt.AlignLeft,   // Имя кассира
    ]
    columnsWidth: [
        60,     // Номер смены
        150,    // Дата открытия
        150,    // Дата закрытия
        tableAvailableWidth - 360,  // Имя кассира
    ]

    // Обработчик
    DialogHandler { id: handler }

    onAccept: (index) => handler.sendAnswer(model.getShiftByRow(index.row))
    onReject: handler.sendAnswer(-1)

    EventFilterConnector {
        filter: DialogEventFilter {
            onOk: selectCurrentIndex()
            onCancel: reject()
        }
    }

    Component.onCompleted: model.prepare(params.first, params.serialNumber)
}
